AgentSniff Dashboard

# ⊘ AGENTSNIFF

AI Agent Network Scanner
Agents Found
—
Confirmed
—
High Confidence
—
Suspected
—
Scan Duration
—
Detectors
—
⊘

### Ready to Scan

Enter a network range and click Scan to detect AI agents

— AgentSniff ready

## ⚙ Alert Settings

### General

Alerts
Enable alert notifications
Min Agents
Min Confidence
Cooldown (s)

### Webhook

URL

### Email (SMTP)

SMTP Host
SMTP Port
Username
Password
TLS
Use STARTTLS
From
To